@@ -1,6 +1,13 @@
 from typing import Coroutine
 import asyncio
 
+def __ensure_event_loop():
+    try:
+        asyncio.get_event_loop()
+
+    except:
+        asyncio.set_event_loop(asyncio.new_event_loop())
+
 
 def sync(coroutine: Coroutine):
     """
@@ -12,6 +19,7 @@ def sync(coroutine: Coroutine):
     Returns:
         该异步函数的返回值
     """
+    __ensure_event_loop()
     loop = asyncio.get_event_loop()
     return loop.run_until_complete(coroutine)
 
